import { API as API$1 } from "../../../scw/api.js";
import { urlParams, validatePathParam } from "../../../helpers/marshalling.js";
import "../../../vendor/base64/index.js";
import { enrichForPagination } from "../../../scw/fetch/resource-paginator.js";
import { unmarshalGetConsumptionResponse, unmarshalListInvoicesResponse, unmarshalListDiscountsResponse } from "./marshalling.gen.js";
class API extends API$1 {
  /**
   * Get current month's consumption. The consumption reflects the amount of
   * money you have spent for the products you have used. The consumption value
   * is monetary and is not computed in real time.
   *
   * @param request - The request {@link GetConsumptionRequest}
   * @returns A Promise of GetConsumptionResponse
   */
  getConsumption = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/billing/v2alpha1/consumption`,
      urlParams: urlParams([
        "organization_id",
        request.organizationId ?? this.client.settings.defaultOrganizationId
      ])
    },
    unmarshalGetConsumptionResponse
  );
  pageOfListInvoices = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/billing/v2alpha1/invoices`,
      urlParams: urlParams(
        ["invoice_type", request.invoiceType],
        ["order_by", request.orderBy],
        ["organization_id", request.organizationId],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["started_after", request.startedAfter],
        ["started_before", request.startedBefore]
      )
    },
    unmarshalListInvoicesResponse
  );
  /**
   * List invoices. List all your invoices, filtering by `start_date` and
   * `invoice_type`. Each invoice has its own ID.
   *
   * @param request - The request {@link ListInvoicesRequest}
   * @returns A Promise of ListInvoicesResponse
   */
  listInvoices = (request = {}) => enrichForPagination("invoices", this.pageOfListInvoices, request);
  /**
   * Download an invoice. Download a specific invoice, specified by its ID.
   *
   * @param request - The request {@link DownloadInvoiceRequest}
   * @returns A Promise of Blob
   */
  downloadInvoice = (request) => this.client.fetch({
    method: "GET",
    path: `/billing/v2alpha1/invoices/${validatePathParam("invoiceId", request.invoiceId)}/download`,
    urlParams: urlParams(["dl", 1], ["file_type", request.fileType]),
    responseType: "blob"
  });
  pageOfListDiscounts = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/billing/v2alpha1/discounts`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["organization_id", request.organizationId],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    unmarshalListDiscountsResponse
  );
  /**
   * List all user's discounts. List all discounts for an organization and
   * usable categories/products/offers/references/regions/zones where the
   * discount can be applied.
   *
   * @param request - The request {@link ListDiscountsRequest}
   * @returns A Promise of ListDiscountsResponse
   */
  listDiscounts = (request = {}) => enrichForPagination("discounts", this.pageOfListDiscounts, request);
}
export {
  API
};
