import { API as ParentAPI } from '../../../bridge';
import type { Region, WaitForOptions } from '../../../bridge';
import type { AuthExternalNodeRequest, Cluster, CreateClusterRequest, CreateExternalNodeRequest, CreatePoolRequest, DeleteClusterRequest, DeleteNodeRequest, DeletePoolRequest, ExternalNode, ExternalNodeAuth, GetClusterKubeConfigRequest, GetClusterRequest, GetNodeMetadataRequest, GetNodeRequest, GetPoolRequest, GetVersionRequest, ListClusterAvailableTypesRequest, ListClusterAvailableTypesResponse, ListClusterAvailableVersionsRequest, ListClusterAvailableVersionsResponse, ListClusterTypesRequest, ListClusterTypesResponse, ListClustersRequest, ListClustersResponse, ListNodesRequest, ListNodesResponse, ListPoolsRequest, ListPoolsResponse, ListVersionsRequest, ListVersionsResponse, MigrateClusterToRoutedIPsRequest, Node, NodeMetadata, Pool, RebootNodeRequest, ReplaceNodeRequest, ResetClusterAdminTokenRequest, SetClusterTypeRequest, UpdateClusterRequest, UpdatePoolRequest, UpgradeClusterRequest, UpgradePoolRequest, Version } from './types.gen';
/**
 * Kubernetes API.
 *
 * This API allows you to manage Kubernetes Kapsule and Kosmos clusters.
 */
export declare class API extends ParentAPI {
    /** Lists the available regions of the API. */
    static readonly LOCALITIES: Region[];
    protected pageOfListClusters: (request?: Readonly<ListClustersRequest>) => Promise<ListClustersResponse>;
    /**
     * List Clusters. List all existing Kubernetes clusters in a specific region.
     *
     * @param request - The request {@link ListClustersRequest}
     * @returns A Promise of ListClustersResponse
     */
    listClusters: (request?: Readonly<ListClustersRequest>) => Promise<ListClustersResponse> & {
        all: () => Promise<Cluster[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Cluster[], void, void>;
    };
    /**
     * Create a new Cluster. Create a new Kubernetes cluster in a Scaleway region.
     *
     * @param request - The request {@link CreateClusterRequest}
     * @returns A Promise of Cluster
     */
    createCluster: (request: Readonly<CreateClusterRequest>) => Promise<Cluster>;
    /**
     * Get a Cluster. Retrieve information about a specific Kubernetes cluster.
     *
     * @param request - The request {@link GetClusterRequest}
     * @returns A Promise of Cluster
     */
    getCluster: (request: Readonly<GetClusterRequest>) => Promise<Cluster>;
    /**
     * Waits for {@link Cluster} to be in a final state.
     *
     * @param request - The request {@link GetClusterRequest}
     * @param options - The waiting options
     * @returns A Promise of Cluster
     */
    waitForCluster: (request: Readonly<GetClusterRequest>, options?: Readonly<WaitForOptions<Cluster>>) => Promise<Cluster>;
    /**
     * Update a Cluster. Update information on a specific Kubernetes cluster. You
     * can update details such as its name, description, tags and configuration.
     * To upgrade a cluster, you will need to use the dedicated endpoint.
     *
     * @param request - The request {@link UpdateClusterRequest}
     * @returns A Promise of Cluster
     */
    updateCluster: (request: Readonly<UpdateClusterRequest>) => Promise<Cluster>;
    /**
     * Delete a Cluster. Delete a specific Kubernetes cluster and all its
     * associated pools and nodes. Note that this method will not delete any Load
     * Balancer or Block Volume that are associated with the cluster.
     *
     * @param request - The request {@link DeleteClusterRequest}
     * @returns A Promise of Cluster
     */
    deleteCluster: (request: Readonly<DeleteClusterRequest>) => Promise<Cluster>;
    /**
     * Upgrade a Cluster. Upgrade a specific Kubernetes cluster and possibly its
     * associated pools to a specific and supported Kubernetes version.
     *
     * @param request - The request {@link UpgradeClusterRequest}
     * @returns A Promise of Cluster
     */
    upgradeCluster: (request: Readonly<UpgradeClusterRequest>) => Promise<Cluster>;
    /**
     * Change the Cluster type. Change the type of a specific Kubernetes cluster.
     * To see the possible values you can enter for the `type` field, [list
     * available cluster
     * types](#path-clusters-list-available-cluster-types-for-a-cluster).
     *
     * @param request - The request {@link SetClusterTypeRequest}
     * @returns A Promise of Cluster
     */
    setClusterType: (request: Readonly<SetClusterTypeRequest>) => Promise<Cluster>;
    /**
     * List available versions for a Cluster. List the versions that a specific
     * Kubernetes cluster is allowed to upgrade to. Results will include every
     * patch version greater than the current patch, as well as one minor version
     * ahead of the current version. Any upgrade skipping a minor version will not
     * work.
     *
     * @param request - The request {@link ListClusterAvailableVersionsRequest}
     * @returns A Promise of ListClusterAvailableVersionsResponse
     */
    listClusterAvailableVersions: (request: Readonly<ListClusterAvailableVersionsRequest>) => Promise<ListClusterAvailableVersionsResponse>;
    /**
     * List available cluster types for a cluster. List the cluster types that a
     * specific Kubernetes cluster is allowed to switch to.
     *
     * @param request - The request {@link ListClusterAvailableTypesRequest}
     * @returns A Promise of ListClusterAvailableTypesResponse
     */
    listClusterAvailableTypes: (request: Readonly<ListClusterAvailableTypesRequest>) => Promise<ListClusterAvailableTypesResponse>;
    protected _getClusterKubeConfig: (request: Readonly<GetClusterKubeConfigRequest>) => Promise<Blob>;
    /**
     * Reset the admin token of a Cluster. Reset the admin token for a specific
     * Kubernetes cluster. This will revoke the old admin token (which will not be
     * usable afterwards) and create a new one. Note that you will need to
     * download kubeconfig again to keep interacting with the cluster.
     *
     * @param request - The request {@link ResetClusterAdminTokenRequest}
     */
    resetClusterAdminToken: (request: Readonly<ResetClusterAdminTokenRequest>) => Promise<void>;
    /**
     * Migrate a cluster to Routed IPs. Migrate the nodes of an existing cluster
     * to Routed IPs and enable Routed IPs for all future nodes.
     *
     * @param request - The request {@link MigrateClusterToRoutedIPsRequest}
     * @returns A Promise of Cluster
     */
    migrateClusterToRoutedIPs: (request: Readonly<MigrateClusterToRoutedIPsRequest>) => Promise<Cluster>;
    protected pageOfListPools: (request: Readonly<ListPoolsRequest>) => Promise<ListPoolsResponse>;
    /**
     * List Pools in a Cluster. List all the existing pools for a specific
     * Kubernetes cluster.
     *
     * @param request - The request {@link ListPoolsRequest}
     * @returns A Promise of ListPoolsResponse
     */
    listPools: (request: Readonly<ListPoolsRequest>) => Promise<ListPoolsResponse> & {
        all: () => Promise<Pool[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Pool[], void, void>;
    };
    /**
     * Create a new Pool in a Cluster. Create a new pool in a specific Kubernetes
     * cluster.
     *
     * @param request - The request {@link CreatePoolRequest}
     * @returns A Promise of Pool
     */
    createPool: (request: Readonly<CreatePoolRequest>) => Promise<Pool>;
    /**
     * Get a Pool in a Cluster. Retrieve details about a specific pool in a
     * Kubernetes cluster.
     *
     * @param request - The request {@link GetPoolRequest}
     * @returns A Promise of Pool
     */
    getPool: (request: Readonly<GetPoolRequest>) => Promise<Pool>;
    /**
     * Waits for {@link Pool} to be in a final state.
     *
     * @param request - The request {@link GetPoolRequest}
     * @param options - The waiting options
     * @returns A Promise of Pool
     */
    waitForPool: (request: Readonly<GetPoolRequest>, options?: Readonly<WaitForOptions<Pool>>) => Promise<Pool>;
    /**
     * Upgrade a Pool in a Cluster. Upgrade the Kubernetes version of a specific
     * pool. Note that it only works if the targeted version matches the cluster's
     * version.
     *
     * @param request - The request {@link UpgradePoolRequest}
     * @returns A Promise of Pool
     */
    upgradePool: (request: Readonly<UpgradePoolRequest>) => Promise<Pool>;
    /**
     * Update a Pool in a Cluster. Update the attributes of a specific pool, such
     * as its desired size, autoscaling settings, and tags.
     *
     * @param request - The request {@link UpdatePoolRequest}
     * @returns A Promise of Pool
     */
    updatePool: (request: Readonly<UpdatePoolRequest>) => Promise<Pool>;
    /**
     * Delete a Pool in a Cluster. Delete a specific pool from a cluster. Note
     * that all the pool's nodes will also be deleted.
     *
     * @param request - The request {@link DeletePoolRequest}
     * @returns A Promise of Pool
     */
    deletePool: (request: Readonly<DeletePoolRequest>) => Promise<Pool>;
    /**
     * Fetch node metadata. Rerieve metadata to instantiate a Kapsule/Kosmos node.
     * This method is not intended to be called by end users but rather
     * programmatically by the node-installer.
     *
     * @param request - The request {@link GetNodeMetadataRequest}
     * @returns A Promise of NodeMetadata
     */
    getNodeMetadata: (request?: Readonly<GetNodeMetadataRequest>) => Promise<NodeMetadata>;
    /**
     * Authenticate Kosmos external node. Creates a newer Kosmos node and returns
     * its token. This method is not intended to be called by end users but rather
     * programmatically by the node-installer.
     *
     * @param request - The request {@link AuthExternalNodeRequest}
     * @returns A Promise of ExternalNodeAuth
     */
    authExternalNode: (request: Readonly<AuthExternalNodeRequest>) => Promise<ExternalNodeAuth>;
    /**
     * Create a Kosmos node. Retrieve metadata for a Kosmos node. This method is
     * not intended to be called by end users but rather programmatically by the
     * kapsule-node-agent.
     *
     * @param request - The request {@link CreateExternalNodeRequest}
     * @returns A Promise of ExternalNode
     */
    createExternalNode: (request: Readonly<CreateExternalNodeRequest>) => Promise<ExternalNode>;
    protected pageOfListNodes: (request: Readonly<ListNodesRequest>) => Promise<ListNodesResponse>;
    /**
     * List Nodes in a Cluster. List all the existing nodes for a specific
     * Kubernetes cluster.
     *
     * @param request - The request {@link ListNodesRequest}
     * @returns A Promise of ListNodesResponse
     */
    listNodes: (request: Readonly<ListNodesRequest>) => Promise<ListNodesResponse> & {
        all: () => Promise<Node[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Node[], void, void>;
    };
    /**
     * Get a Node in a Cluster. Retrieve details about a specific Kubernetes Node.
     *
     * @param request - The request {@link GetNodeRequest}
     * @returns A Promise of Node
     */
    getNode: (request: Readonly<GetNodeRequest>) => Promise<Node>;
    /**
     * Waits for {@link Node} to be in a final state.
     *
     * @param request - The request {@link GetNodeRequest}
     * @param options - The waiting options
     * @returns A Promise of Node
     */
    waitForNode: (request: Readonly<GetNodeRequest>, options?: Readonly<WaitForOptions<Node>>) => Promise<Node>;
    /**
     * Replace a Node in a Cluster. Replace a specific Node. The node will first
     * be cordoned (scheduling will be disabled on it). The existing pods on the
     * node will then be drained and rescheduled onto another schedulable node.
     * Note that when there is not enough space to reschedule all the pods (such
     * as in a one-node cluster), disruption of your applications can be
     * expected.
     *
     * @deprecated
     * @param request - The request {@link ReplaceNodeRequest}
     * @returns A Promise of Node
     */
    replaceNode: (request: Readonly<ReplaceNodeRequest>) => Promise<Node>;
    /**
     * Reboot a Node in a Cluster. Reboot a specific Node. The node will first be
     * cordoned (scheduling will be disabled on it). The existing pods on the node
     * will then be drained and rescheduled onto another schedulable node. Note
     * that when there is not enough space to reschedule all the pods (such as in
     * a one-node cluster), disruption of your applications can be expected.
     *
     * @param request - The request {@link RebootNodeRequest}
     * @returns A Promise of Node
     */
    rebootNode: (request: Readonly<RebootNodeRequest>) => Promise<Node>;
    /**
     * Delete a Node in a Cluster. Delete a specific Node. Note that when there is
     * not enough space to reschedule all the pods (such as in a one-node
     * cluster), disruption of your applications can be expected.
     *
     * @param request - The request {@link DeleteNodeRequest}
     * @returns A Promise of Node
     */
    deleteNode: (request: Readonly<DeleteNodeRequest>) => Promise<Node>;
    /**
     * List all available Versions. List all available versions for the creation
     * of a new Kubernetes cluster.
     *
     * @param request - The request {@link ListVersionsRequest}
     * @returns A Promise of ListVersionsResponse
     */
    listVersions: (request?: Readonly<ListVersionsRequest>) => Promise<ListVersionsResponse>;
    /**
     * Get a Version. Retrieve a specific Kubernetes version and its details.
     *
     * @param request - The request {@link GetVersionRequest}
     * @returns A Promise of Version
     */
    getVersion: (request: Readonly<GetVersionRequest>) => Promise<Version>;
    protected pageOfListClusterTypes: (request?: Readonly<ListClusterTypesRequest>) => Promise<ListClusterTypesResponse>;
    /**
     * List cluster types. List available cluster types and their technical
     * details.
     *
     * @param request - The request {@link ListClusterTypesRequest}
     * @returns A Promise of ListClusterTypesResponse
     */
    listClusterTypes: (request?: Readonly<ListClusterTypesRequest>) => Promise<ListClusterTypesResponse> & {
        all: () => Promise<import("./types.gen").ClusterType[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").ClusterType[], void, void>;
    };
}
