import randomName from "@scaleway/random-name";
import { isJSONObject } from "../../../helpers/json.js";
import { unmarshalDate, unmarshalArrayOfObject } from "../../../helpers/marshalling.js";
import "../../../vendor/base64/index.js";
const unmarshalPrivateNetwork = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'PrivateNetwork' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: unmarshalDate(data.created_at),
    id: data.id,
    name: data.name,
    organizationId: data.organization_id,
    projectId: data.project_id,
    subnets: data.subnets,
    tags: data.tags,
    updatedAt: unmarshalDate(data.updated_at),
    zone: data.zone
  };
};
const unmarshalListPrivateNetworksResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListPrivateNetworksResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    privateNetworks: unmarshalArrayOfObject(
      data.private_networks,
      unmarshalPrivateNetwork
    ),
    totalCount: data.total_count
  };
};
const marshalCreatePrivateNetworkRequest = (request, defaults) => ({
  name: request.name || randomName("pn"),
  project_id: request.projectId ?? defaults.defaultProjectId,
  subnets: request.subnets,
  tags: request.tags
});
const marshalUpdatePrivateNetworkRequest = (request, defaults) => ({
  name: request.name,
  subnets: request.subnets,
  tags: request.tags
});
export {
  marshalCreatePrivateNetworkRequest,
  marshalUpdatePrivateNetworkRequest,
  unmarshalListPrivateNetworksResponse,
  unmarshalPrivateNetwork
};
